@@ -108,14 +108,14 @@ class Plate():
         size = dat.pivot(index='row', columns='col', values='size')
         size.index.name = None
         size.index = size.index.map(str)
-        size.columns.name=None
+        size.columns.name = None
         size.columns = size.columns.map(str)
         self.pos_data['Colony_size'] = size
         
         circularity = dat.pivot(index='row', columns='col', values='circularity')
         circularity.index.name = None
         circularity.index = circularity.index.map(str)
-        circularity.columns.name=None
+        circularity.columns.name = None
         circularity.columns = circularity.columns.map(str)
         self.pos_data['Colony_circularity'] = circularity
         
@@ -127,10 +127,29 @@ class Plate():
         size = dat.pivot(index='row', columns='column', values='mean_intensity')
         size.index.name = None
         size.index = size.index.map(str)
-        size.columns.name=None
+        size.columns.name = None
         size.columns = size.columns.map(str)
         
         self.pos_data['Colony_size'] = size
+    
+    def read_pyphebatch_single_image(self):
+        '''Read  column from pyphe-quantify redness output file'''
+        
+        dat = pd.read_csv(self.meta_data['Data_path'])
+
+        size = dat.pivot(index='row', columns='column', values='area')
+        size.index.name = None
+        size.index = size.index.map(str)
+        size.columns.name = None
+        size.columns = size.columns.map(str)        
+        self.pos_data['Colony_size'] = size
+             
+        circularity = dat.pivot(index='row', columns='column', values='circularity')
+        circularity.index.name = None
+        circularity.index = circularity.index.map(str)
+        circularity.columns.name = None
+        circularity.columns = circularity.columns.map(str)
+        self.pos_data['Colony_circularity'] = circularity
         
     def read_pgc_single_image(self):
         '''Read pyphe-growthcurves output file'''
@@ -147,9 +166,9 @@ class Plate():
             tf.columns = tf.columns.map(str)
             
             if c == 'max_slope':
-                self.pos_data['Colony_size'] = tf
+                self.pos_data['Colony_size'] = tf.astype(float)
             else:
-                self.pos_data[c] = tf
+                self.pos_data[c] = tf.astype(float)
 
         
     def read_layout_single_plate(self, kwargs={'header':None}):
@@ -343,6 +362,10 @@ class Plate():
         '''
 
         data = self.pos_data[inkey]
+        ##In some rare cases the input DataFrame can be empty. In that case, just set to an empty DataFrame
+        if data.empty:
+            self.pos_data[outkey] = pd.DataFrame([[]])
+            return None
         data = data.unstack()
 
         #Ignore na
@@ -385,15 +408,20 @@ class Plate():
         '''
         unstacked = []
         for k, frame in self.pos_data.iteritems():
+            if frame.empty:
+                continue
             l_unstacked = frame.copy()
             l_unstacked.columns.name = 'Column'
             l_unstacked.index.name = 'Row'
             l_unstacked = l_unstacked.unstack()
             l_unstacked.name = k
             unstacked.append(l_unstacked)
-
-        long_data = pd.concat(unstacked, axis=1)
-        long_data = long_data.reset_index()
+        if len(unstacked) == 0:
+            warn('No data associated with Plate %s. Please check input data'%self.plateid)
+            return pd.DataFrame([[]])
+        else:
+            long_data = pd.concat(unstacked, axis=1)
+            long_data = long_data.reset_index()
 
         return long_data
 
@@ -470,6 +498,9 @@ def pyphe_cmd(wdirectory=None, grid_norm=None, out_ld=None, qcplots=None, check_
         
     elif input_type == 'pyphe-growthcurves':
         exp.plates.map(Plate.read_pgc_single_image)
+        
+    elif input_type == 'pyphe-quantify-batch':
+                exp.plates.map(Plate.read_pyphebatch_single_image)
     
     else:
         raise ValueError('Unrecignised input_type')
